%define tarname	Sphinx

# disable these for bootstrapping nose and sphinx
%define enable_tests 0
%define enable_doc 0

%if !%{enable_doc}
%define __noautoreq ".*sphinx-rtd-theme.*\|.*alabaster.*"
%endif

Summary:	Python documentation generator

Name:		python3-sphinx
Version:	1.3.1
Release:	2
Source0:	http://pypi.python.org/packages/source/S/Sphinx/Sphinx-%{version}.tar.gz
Patch0:	        Sphinx-1.2.2-mantarget.patch
Patch1:         Sphinx-1.2.2-babel-option.patch
License:	BSD
Group:		Development/Python
Url:		http://sphinx.pocoo.org/
BuildArch:	noarch
%if %{enable_doc}
BuildRequires:	python3-docutils
BuildRequires:	python3-jinja2
BuildRequires:  python3-six
BuildRequires:  python3-sphinx-theme-alabaster
BuildRequires:  python3-sphinx_rtd_theme
%endif
%if %{enable_tests}
BuildRequires:	python3-nose
BuildRequires:	python3-pygments
BuildRequires:  python3-jinja2
%endif
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
BuildRequires:	python3-distribute

Requires: 	python3-sphinx-theme-alabaster
Requires:	python3-sphinx_rtd_theme
Requires:	python3-pkg-resources
Requires:	python3-docutils
Requires:	python3-pygments
Requires:	python3-jinja2

%description
Sphinx is a tool that facilitates the creation of beautiful
documentation for Python projects from reStructuredText sources. It
was originally created to format the new documentation for Python, but
has since been cleaned up in the hope that it will be useful in many
other projects.

%if %{enable_doc}
%package doc
Summary:	Documentation for %{name}

Group:		Development/Python
License:	BSD
Requires:	%{name} = %{EVRD}
Conflicts:	python-sphinx-doc

%description doc
Sphinx is a tool that makes it easy to create intelligent and
beautiful documentation for Python projects (or other documents
consisting of multiple reStructuredText sources), written by Georg
Brandl. It was originally created to translate the new Python
documentation, but has now been cleaned up in the hope that it will be
useful to many other projects.

This package contains documentation in reST and HTML formats.
%endif

%prep
%setup -qn %{tarname}-%{version}
%patch0 -p1 -b .mantarget
%patch1 -p1 -b .babel
sed '1d' -i sphinx/pycode/pgen2/token.py
sed -i s'@#!/usr/bin/env python@#!/usr/bin/python3@' *py

%build
python3 setup.py build

%if %{enable_doc}
pushd doc
make html
make man
rm -rf _build/html/.buildinfo
mv _build/html ..
popd
%endif


%install
python3 setup.py install --skip-build --root=%{buildroot} 

%if %{enable_doc}
pushd doc
# Deliver man pages
install -d %{buildroot}%{_mandir}/man1
mv _build/man/sphinx-*.1 %{buildroot}%{_mandir}/man1/
for f in %{buildroot}%{_mandir}/man1/sphinx-*.1;
do
    cp -p $f $(echo $f | sed -e "s|.1$|-%{python3_version}.1|")
done
popd

# Deliver rst files
rm -rf doc/_build
sed -i 's|python ../sphinx-build.py|/usr/bin/sphinx-build|' doc/Makefile
mv doc reST
%endif

# Move language files to /usr/share;
# patch to support this incorporated in 0.6.6
pushd %{buildroot}%{py3_puresitedir}

for lang in `find sphinx/locale -maxdepth 1 -mindepth 1 -type d -not -path '*/\.*' -printf "%f "`;
do
  install -d %{buildroot}%{_datadir}/sphinx/locale/$lang
  install -d %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.js \
     %{buildroot}%{_datadir}/sphinx/locale/$lang/
  mv sphinx/locale/$lang/LC_MESSAGES/sphinx.mo \
    %{buildroot}%{_datadir}/locale/$lang/LC_MESSAGES/
  rm -rf sphinx/locale/$lang
done
popd
%find_lang sphinx

# Language files; Since these are javascript, it's not immediately obvious to
# find_lang that they need to be marked with a language.
(cd %{buildroot} && find . -name 'sphinx.js') | sed -e 's|^.||' | sed -e \
  's:\(.*/locale/\)\([^/_]\+\)\(.*\.js$\):%lang(\2) \1\2\3:' \
  >> sphinx.lang


%check
%if %{enable_tests}
pushd tests
python3 run.py
popd
%endif

%files -f sphinx.lang
%doc AUTHORS CHANGES EXAMPLES LICENSE
%{_bindir}/sphinx-*
%{py3_puresitedir}/*
%dir %{_datadir}/sphinx/
%dir %{_datadir}/sphinx/locale
%dir %{_datadir}/sphinx/locale/*
%if %{enable_doc}
%{_mandir}/man1/*
%endif

%if %{enable_doc}
%files doc
%doc html reST
%endif

%changelog

* Sun Apr 24 2016 Denis Silakov <dsilakov@gmail.com> 1.3.1-2
- (ab2f31d) Require additional themes by default


